import { AxiosInstance, AxiosPromise, AxiosRequestConfig } from 'axios';
import { Store } from 'redux';
export declare const GET: string;
export declare const POST: string;
export declare const PUT: string;
export declare const DELETE: string;
export declare const HEAD: string;
export declare const OPTIONS: string;
export declare const logPrefix: string;
export declare const RETRIEVEJS_PREFIX_ACTIONS: string;
export declare const LOAD = "load";
export declare const SUCCESS = "success";
export declare const FAILED = "failed";
export interface ApiEndpoint {
    path: string;
    method: string;
}
export interface ApiEndpoints {
    [endpointName: string]: ApiEndpoint;
}
export interface AxiosInstanceWithOptions extends AxiosInstance {
    options: (path: string, config: AxiosRequestConfig | undefined) => AxiosPromise;
}
export declare type ApiRequester = (config?: AxiosRequestConfig, params?: {}) => AxiosPromise;
export interface Api {
    [key: string]: ApiRequester;
}
/**
 * Creates an api object which contains functions depending on the endpoint object passed in the 1st parameter.
 *
 * ### Example (es imports)
 * ```js
 * import { createApi } from 'retrievejs';
 * const endpoints = {
        getMock: { path: 'http://www.mocky.io/v2/5aab93182e00004900138dd4', method: 'get' }
    };
 * const api = createApi(endpoints);
 * // => api.getMock().then((response) => console.log(response))
 * ```
 * @param {ApiEndpoints} endpoints
 * @param store
 * @param {AxiosInstanceWithOptions} _axios
 * @return {Api}
 */
export declare const createApi: (endpoints: ApiEndpoints, store: Store<any>, _axios?: AxiosInstanceWithOptions | undefined) => Api;
