import * as React from 'react';
import { ApiRequester } from './createApi';
import { AxiosRequestConfig } from 'axios';
export declare type QueryType = (func: ApiRequester, propName?: string, requestConfig?: AxiosRequestConfig, params?: object) => (WrappedComponent: React.SFC | React.ComponentClass) => React.SFC | React.ComponentClass;
/**
 * A query HOC for doing a request when the passed component is mounted.
 *
 * ### Refresh example
 * ```js
 *  ...
 *  // refresh request:
 *  this.props.myRequest.refreshRequest()
 *  ...
 * ```
 *
 * ### Example (es imports)
 * ```js
 * import { query } from 'retrievejs';
 * const enhance = query(api.getMockData, 'myRequest')
 * export const MyComponent = enhance((props) => <pre>{JSON.stringify(props, null, 4)}</pre>)
 * ```
 * ### Data structure passed to props
 * ```js
 * const MyComponent = (props) => {
 *      // props.myRequest.request
 *      //      => axios request object
 *      // props.myRequest.isFetching
 *      //      => whether or not we're currently fetching a resource
 *      // props.myRequest.failed
 *      //      => if the request failed, if yes, equals to true
 * }
 * ```
 * @param {ApiRequester} func
 * @param {string} propName
 * @param {{}} requestConfig
 * @param {{}} params
 * @return {(WrappedComponent) => QueryHOC}
 */
export declare const query: QueryType;
